from __future__ import print_function
import argparse
import logging

parser   = argparse.ArgumentParser()
add      = parser.add_argument
defaults = parser.set_defaults
parse    = parser.parse_args

add("--mpi_ni", type=int, default=1, help="number of x processors")
add("--mpi_nj", type=int, default=1, help="number of y processors")
add("--hydrostatic", action='store_true')
add("--llm", type=int)
add("--dt", type=float, help='Time step in seconds')
add("--debug", default=[], type=lambda str : str.split(','), 
    help='Comma-separated list of modules that will display debug information')

def noop(*args, **kwargs): pass

def ignore_first(fun):
    def f(self, *args, **kwargs) : fun(*args, **kwargs)
    return f

def getLogger(modulename='dynamico.main'):
    # two logger are created
    # the 'master' logger will be muted if current MPI process is not master
    # log your messages through master two avoid massive logs with 1000+ MPI processes
    master, world = logging.getLogger(modulename), logging.getLogger('%s.world'%modulename) 
    arglist = parser.parse_args()
    debug=False
    if modulename in ['dynamico.%s'%name for name in arglist.debug] : debug=True
    if 'all' in arglist.debug : debug=True
    if debug:
#        print('Debug ON for module %s'%modulename)
        master.setLevel(logging.DEBUG)
        world.setLevel(logging.DEBUG)
    else:
        master.setLevel(logging.INFO)
        world.setLevel(logging.INFO)
    masters[modulename]=master
    return master, world

def not_master():
    for logger in masters.values():
        logger.setLevel(logging.CRITICAL)

masters = {}
logging.basicConfig()
